@@ -11,7 +11,8 @@ from wedeliver_core.helpers.get_prefix import get_prefix
 
 
 def route(path, methods=["GET"], schema=None, many=False, allowed_roles=None, require_auth=True,
-          append_auth_args=None):
+          append_auth_args=None, 
+          allowed_permissions=None):
     app = WeDeliverCore.get_app()
 
     def factory(func):
@@ -19,7 +20,7 @@ def route(path, methods=["GET"], schema=None, many=False, allowed_roles=None, re
         @app.route(get_prefix(path), methods=methods)
         @handle_response
         @handle_exceptions
-        @handle_auth(require_auth=require_auth, append_auth_args=append_auth_args, allowed_roles=allowed_roles)
+        @handle_auth(require_auth=require_auth, append_auth_args=append_auth_args, allowed_roles=allowed_roles,allowed_permissions=allowed_permissions)
         @serializer(schema=schema, many=many)
         @wraps(func)
         def decorator(*args, **kwargs):
