@@ -7,9 +7,10 @@ from wedeliver_core.helpers.exceptions import (
     AppValidationError,
     AppMissingAuthError,
 )
+from wedeliver_core.helpers.acl_enum import Permission
 
 
-def handle_auth(require_auth, append_auth_args=None, allowed_roles=None):
+def handle_auth(require_auth, append_auth_args=None, allowed_roles=None, allowed_permissions=None):
     def factory(func):
         @wraps(func)
         def inner_function(*args, **kws):
@@ -23,16 +24,7 @@ def handle_auth(require_auth, append_auth_args=None, allowed_roles=None):
             if "country_code" not in request.headers and request.endpoint != "health_check":
                 raise AppValidationError("Country Code is Required (c)")
 
-            user = verify_user_token(token=token)
-
-            has_valid_role = True
-            if allowed_roles and len(allowed_roles):
-                user_role = user.get('role')
-                if user_role not in allowed_roles:
-                    has_valid_role = False
-
-            if not has_valid_role:
-                raise AppMissingAuthError("You have not enough permission")
+            user = verify_user_token(token=token,allowed_permissions=allowed_permissions)
 
             if append_auth_args and isinstance(append_auth_args, list):
                 for arg in append_auth_args:
