@@ -1,5 +1,5 @@
 from app import app
-from wedeliver_core.wedeliver_core.helpers.amazon.get_s3_client import get_s3_client
+from wedeliver_core.helpers.amazon.get_s3_client import get_s3_client
 
 
 def get_file_url(s3_path, s3_client=None):
