@@ -26,9 +26,9 @@ def send_notification_message(
         else "development",
         channel,
     )
-
+    datetime_now = datetime.now().strftime("%Y-%m-%d %H:%M")
     message = "Node: {0}\nEnv:{3}\nDate: {1}\n{2}".format(
-        platform.node(), datetime.now(), message, str(app.config.get("FLASK_ENV"))
+        platform.node(),datetime_now, message, str(app.config.get("FLASK_ENV"))
     )
     data = {
         "notification_method": "slack",
